function calculateRating (ratings) {
  const numberOfRatings = ratings.length
  const sumOfRatings = ratings.reduce(
    (accumulator, rating) => accumulator + rating.value,
    0
  )
  console.log(ratings, sumOfRatings, numberOfRatings)
  return numberOfRatings ? sumOfRatings / numberOfRatings : '-'
}

const TrainingArchive = props => (
  <div>
    <h2>Training Archive</h2>
    {console.log('archive', props)}
    <ol>
      {props.trainings.map(training => (
        <TrainingHint key={training.id} training={training} />
      ))}
    </ol>
  </div>
)

const TrainingHint = props => (
  <div>
    <div>{props.training.date}</div>
    <div>{props.training.title}</div>
  </div>
)

const Training = props => (
  <article>
    <h2>{props.title}</h2>
    <aside>
      <div id='trainingType'>
        <span className='caption'>Type: </span>
        <span className='data'>{props.type.name}</span>
      </div>
      <div id='trainingDate'>
        <span className='caption'>Date: </span>
        <date className='data'>
          {new Date(props.trainingDate).toLocaleDateString()}
        </date>
      </div>
      <div id='trainingLocation'>
        <span className='caption'>Location: </span>
        <span className='data'>{props.location}</span>
      </div>
      <div id='trainingRegistrations'>
        <span className='caption'>Registrations: </span>
        <span className='data'>
          {props.registration.length} <a href=''>Register!</a>
        </span>
      </div>
      <div id='trainingAttendance'>
        <span className='caption'>Attendance: </span>
        <span className='data'>{props.attendance}</span>
      </div>
      <div id='trainingRatings'>
        <span className='caption'>Rating: </span>
        <span className='data'>
          {calculateRating(props.ratings)} [
          <a href=''>{props.ratings.length}</a>] Rate it!
          <a href=''>*</a>
          <a href=''>*</a>
          <a href=''>*</a>
          <a href=''>*</a>
          <a href=''>*</a>
        </span>
      </div>
    </aside>
    <section>
      <h3>Content</h3>
      <ol>
        {props.content
          .sort(block => block.sequence)
          .map(block => (
            <Block key={block.id} {...block} />
          ))}
      </ol>
      <iframe
        width='560'
        height='315'
        src='https://www.youtube.com/embed/hRz0qPREKho'
        frameborder='0'
        allow='accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture'
        allowfullscreen
      />
    </section>

    <style jsx>
      {`
        article {
          border: 1px solid black;
        }

        article > h2 {
          font-size: 120%;
          font-family: roboto_black;
        }

        aside {
        }

        section {
        }
      `}
    </style>
  </article>
)

const Block = props => (
  <li>
    <h2>{props.title}</h2>
    <p>
      <span className='caption'>Duration: </span>
      <span className='data'>{props.duration}</span>
    </p>
    <p>
      <span className='caption'>Variation: </span>
      <span className='data'>{props.variation}</span>
    </p>
    <p>
      <span className='caption'>Format: </span>
      <span className='data'>
        {props.format.name}{' '}
        <sup>
          <a title={props.format.description}>[?]</a>
        </sup>
      </span>
    </p>
    <p>
      <span className='caption'>Description: </span>
      <span className='data'>{props.description}</span>
    </p>
  </li>
)

class TrainingCreateForm extends React.Component {
  render () {
    return (
      <form>
        <label htmlFor='title'>
          Title
          <input type='text' id='title' />
        </label>
        <label htmlFor='title'>
          Title
          <input type='text' id='title' />
        </label>
        <label htmlFor='title'>
          Title
          <input type='text' id='title' />
        </label>
      </form>
    )
  }
}

export { TrainingArchive }
export default Training
